==> boostcrm-widget-1.0.2.tgz: package/es/store/actions/update-call.action.js <==
import _regeneratorRuntime from "babel-runtime/regenerator";
import _extends from "babel-runtime/helpers/extends";
import _asyncToGenerator from "babel-runtime/helpers/asyncToGenerator";
import * as actions from "./action-type";
import { createAction } from "redux-actions";
import { sendMessage } from "../../connections/websocket";
import { GROUP, TYPE } from "../../commons/constants/websocket";
import { getTenantInfo } from "../../commons/tenant-info";

export var updateCallInfoRequest = createAction(actions.UPDATE_CALL_INFORMATION + ".REQUEST");
export var updateCallInfo = function updateCallInfo(payload, newStatus, channelId) {
  return function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(dispatch, store) {
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              // console.log("updateCallInfo");
              dispatch(updateCallInfoRequest(_extends({}, payload, { status: newStatus })));
              sendMessage({
                group: GROUP.CALL,
                type: TYPE.CALL.UPDATE_CALL_INFORMATION,
                payload: payload,
                tenantInfo: getTenantInfo()
              });

            case 2:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, this);
    }));

    return function (_x, _x2) {
      return _ref.apply(this, arguments);
    };
  }();
};

==> boostcrm-widget-1.0.8.tgz: package/es/store/actions/update-call.action.js <==
import _extends from "@babel/runtime/helpers/extends";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import * as actions from "./action-type";
import { createAction } from "redux-actions";
import { sendMessage } from "../../connections/websocket";
import { GROUP, TYPE } from "../../commons/constants/websocket";
import { getTenantInfo } from "../../commons/tenant-info";
export var updateCallInfoRequest = createAction(actions.UPDATE_CALL_INFORMATION + ".REQUEST");
export var updateCallInfo = function updateCallInfo(payload, newStatus, channelId) {
  return /*#__PURE__*/function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(dispatch, store) {
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              // console.log("updateCallInfo");
              dispatch(updateCallInfoRequest(_extends({}, payload, {
                status: newStatus
              })));
              sendMessage({
                group: GROUP.CALL,
                type: TYPE.CALL.UPDATE_CALL_INFORMATION,
                payload: payload,
                tenantInfo: getTenantInfo()
              });

            case 2:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    }));

    return function (_x, _x2) {
      return _ref.apply(this, arguments);
    };
  }();
};
